# PyAWB

A simple python library to control Arbitrary Waveform Generator (aka Function / Signal Generator) from various manufacturers.

Currently following function generators are supported.

## Siglent
- [Siglent SDG1000X Series Arbitrary Waveform Generator](https://www.siglenteu.com/download/8715/?tmstv=1740404771) 

## Rigol
- [Rigol DG1000Z Series Arbitrary Waveform Generator](https://www.batronix.com/pdf/Rigol/ProgrammingGuide/DG1000Z_ProgrammingGuide_EN.pdf)


## Installation
`pip install pyawg`

## Note:

This project is currently under test with several real instruments. Once finished, this note would be removed.
